@@ -10,12 +10,14 @@ class Tokenizer(Transformer):
     self.__class__.pretrained_translator = pretrained_translator
     self.__class__.tokenizer = AutoTokenizer.from_pretrained(pretrained_translator)
 
-  def predict(self, input_lines, src_lang='en', **kwargs):
-    Transformer.predict(self, input_lines, src_lang=src_lang, **kwargs)
+  def transform(self, input_lines, src_lang='en', output='tokens', **kwargs):
+    Transformer.transform(self, input_lines, src_lang=src_lang, **kwargs)
     tokenizer = self.__class__.tokenizer
     tokenizer.src_lang = src_lang
     encoded_inputs = tokenizer(input_lines, add_special_tokens=False)
-    output_lines = []
-    for input_ids in encoded_inputs["input_ids"]:
-      output_lines.append(tokenizer.convert_ids_to_tokens(input_ids))
-    return output_lines
\ No newline at end of file
+    if output == 'ids':
+      return encoded_inputs["input_ids"]
+    return [
+      tokenizer.convert_ids_to_tokens(input_ids) 
+      for input_ids in encoded_inputs["input_ids"]
+    ]
\ No newline at end of file
